impactlab_tools
===============

Welcome to the Climate Impact Lab's impactlab-tools documentation. This package
hosts tools useful to the entire Climate Impact Lab team, and is installed with
the `impactlab_user <https://github.com/ClimateImpactLab/impactlab_user>`_ package.

For detailed descriptions of all functions available in the API, see the :ref:`API documentation <impactlab-tools-api>`.


Contents
--------

.. toctree::
   :maxdepth: 1

   readme
   whatsnew
   impactlab_tools
   configuration
   contributing
